The DSA Transparency Database

# The DSA Transparency Database: Protection of Minors

## Summary

Attribute | Value
--- | ---
Dates | 2023-09-25 to 2025-03-02 (inclusive)
Platforms reporting Protection of Minors SoRs | 11 out of 44 include keywords, 8 include CSAM
Protection of Minors SoRs | 59.3 megarows out of 27.2 gigarows or 0.2%
Protection of Minors SoRs with keywords | 9.9% of category vs 3.4% of all SoRs
Size of in-memory frames | 49.3 gigabyte

Variable | Value
--- | ---
total_rows | 27,103,404,236
total_rows_with_keywords | 493,395,977
⠀ | ⠀
batch_count | 34,232
⠀ | ⠀
rows | 58,868,237
keywords | 5,609,725
rows_with_keywords | 5,609,706
max_keywords_per_row | 3
⠀ | ⠀
null_decision | 0
visibility_decision_only | 49,564,353
monetary_decision_only | 1
provision_decision_only | 5,543,082
account_decision_only | 3,551,761
visibility_monetary_decision | 27,829
visibility_provision_decision | 12,863
visibility_account_decision | 28,079
monetary_provision_decision | 0
monetary_account_decision | 0
provision_account_decision | 0
monetary_provision_account_decision | 0
visibility_provision_account_decision | 140,269
visibility_monetary_account_decision | 0
visibility_monetary_provision_decision | 0
all_kinds_decision | 0
⠀ | ⠀
max_visibility_per_row | 2
visibility_values | 49,814,189
rows_with_visibility | 49,773,393
null_visibility_decision | 9,094,844
⠀ | ⠀
content_removed | 15,193,845
content_disabled | 550,944
content_demoted | 31,749
content_age_restricted | 10,734,389
content_interaction_restricted | 0
content_labeled | 5
other_visibility | 23,303,257
⠀ | ⠀
monetary_suspension | 0
monetary_termination | 27,830
monetary_other | 0
null_monetary_decision | 58,840,407
⠀ | ⠀
provision_partial_suspension | 5,545,043
provision_total_suspension | 148,516
provision_partial_termination | 322
provision_total_termination | 2,333
null_provision_decision | 53,172,023
⠀ | ⠀
account_suspended | 561,791
account_suspended_null_date | 557,756
account_suspended_until_date | 4,035
account_suspended_until_date_pct | 0.718
account_terminated | 3,158,318
account_terminated_null_date | 3,158,318
account_terminated_until_date | 0
null_account_decision | 55,148,128
⠀ | ⠀
account_type_business | 471,556
account_type_private | 3,355
null_account_type | 58,393,326
⠀ | ⠀
illegal_content | 180,756
incompatible_content | 58,687,481
null_decision_ground | 0
incompatible_content_illegal_yes | 3,880,041
incompatible_content_illegal_no | 292,897
null_incompatible_content_illegal | 54,695,299
⠀ | ⠀
source_article_16 | 245,856
source_trusted_flagger | 671
source_other_notification | 608,915
source_voluntary | 58,012,795
null_source_type | 0
⠀ | ⠀
automated_detection_yes | 50,230,565
automated_detection_no | 8,637,672
null_automated_detection | 0
automated_decision_fully | 30,532,197
automated_decision_partially | 4,178,437
automated_decision_not_automated | 24,157,603
null_automated_decision | 0
⠀ | ⠀
csam | 3,135,143
csam_pct | 5.326
⠀ | ⠀
csam_null_decision | 0
csam_visibility_decision_only | 177,548
csam_monetary_decision_only | 0
csam_provision_decision_only | 2,346,130
csam_account_decision_only | 475,306
csam_visibility_monetary_decision | 0
csam_visibility_provision_decision | 0
csam_visibility_account_decision | 1
csam_monetary_provision_decision | 0
csam_monetary_account_decision | 0
csam_provision_account_decision | 0
csam_monetary_provision_account_decision | 0
csam_visibility_provision_account_decision | 136,158
csam_visibility_monetary_account_decision | 0
csam_visibility_monetary_provision_decision | 0
csam_all_kinds_decision | 0
⠀ | ⠀
csam_max_visibility_per_row | 1
csam_visibility_values | 313,707
csam_rows_with_visibility | 313,707
csam_null_visibility_decision | 2,821,436
⠀ | ⠀
csam_content_removed | 174,406
csam_content_disabled | 3,134
csam_content_demoted | 0
csam_content_age_restricted | 0
csam_content_interaction_restricted | 0
csam_content_labeled | 0
csam_other_visibility | 136,167
⠀ | ⠀
csam_monetary_suspension | 0
csam_monetary_termination | 0
csam_monetary_other | 0
csam_null_monetary_decision | 3,135,143
⠀ | ⠀
csam_provision_partial_suspension | 2,346,130
csam_provision_total_suspension | 136,152
csam_provision_partial_termination | 0
csam_provision_total_termination | 6
csam_null_provision_decision | 652,855
⠀ | ⠀
csam_account_suspended | 369,405
csam_account_suspended_null_date | 369,405
csam_account_suspended_until_date | 0
csam_account_terminated | 242,060
csam_account_terminated_null_date | 242,060
csam_account_terminated_until_date | 0
csam_null_account_decision | 2,523,678
⠀ | ⠀
csam_account_type_business | 0
csam_account_type_private | 96
csam_null_account_type | 3,135,047
⠀ | ⠀
csam_illegal_content | 136,167
csam_incompatible_content | 2,998,976
csam_null_decision_ground | 0
csam_incompatible_content_illegal_yes | 2,997,235
csam_incompatible_content_illegal_no | 0
csam_null_incompatible_content_illegal | 137,908
⠀ | ⠀
csam_source_article_16 | 150,679
csam_source_trusted_flagger | 645
csam_source_other_notification | 136,700
csam_source_voluntary | 2,847,119
csam_null_source_type | 0
⠀ | ⠀
csam_automated_detection_yes | 1,617,674
csam_automated_detection_no | 1,517,469
csam_null_automated_detection | 0
csam_automated_decision_fully | 1,758,500
csam_automated_decision_partially | 3
csam_automated_decision_not_automated | 1,376,640
csam_null_automated_decision | 0

## Table Schemas

### Source Data

Column | Type
--- | ---
uuid | String
decision_visibility | List(Enum(categories=['DECISION_VISIBILITY_CONTENT_REMOVED', 'DECISION_VISIBILITY_CONTENT_DISABLED', 'DECISION_VISIBILITY_CONTENT_DEMOTED', 'DECISION_VISIBILITY_CONTENT_AGE_RESTRICTED', 'DECISION_VISIBILITY_CONTENT_INTERACTION_RESTRICTED', 'DECISION_VISIBILITY_CONTENT_LABELLED', 'DECISION_VISIBILITY_OTHER']))
decision_visibility_other | String
end_date_visibility_restriction | Datetime(time_unit='ms', time_zone=None)
decision_monetary | Enum(categories=['DECISION_MONETARY_SUSPENSION', 'DECISION_MONETARY_TERMINATION', 'DECISION_MONETARY_OTHER'])
decision_monetary_other | String
end_date_monetary_restriction | Datetime(time_unit='ms', time_zone=None)
decision_provision | Enum(categories=['DECISION_PROVISION_PARTIAL_SUSPENSION', 'DECISION_PROVISION_TOTAL_SUSPENSION', 'DECISION_PROVISION_PARTIAL_TERMINATION', 'DECISION_PROVISION_TOTAL_TERMINATION'])
end_date_service_restriction | Datetime(time_unit='ms', time_zone=None)
decision_account | Enum(categories=['DECISION_ACCOUNT_SUSPENDED', 'DECISION_ACCOUNT_TERMINATED'])
end_date_account_restriction | Datetime(time_unit='ms', time_zone=None)
account_type | Enum(categories=['ACCOUNT_TYPE_BUSINESS', 'ACCOUNT_TYPE_PRIVATE'])
decision_ground | Enum(categories=['DECISION_GROUND_ILLEGAL_CONTENT', 'DECISION_GROUND_INCOMPATIBLE_CONTENT'])
decision_ground_reference_url | String
illegal_content_legal_ground | String
illegal_content_explanation | String
incompatible_content_ground | String
incompatible_content_explanation | String
incompatible_content_illegal | Enum(categories=['Yes', 'No'])
category | Enum(categories=['STATEMENT_CATEGORY_ANIMAL_WELFARE', 'STATEMENT_CATEGORY_CONSUMER_INFORMATION', 'STATEMENT_CATEGORY_CYBER_VIOLENCE', 'STATEMENT_CATEGORY_CYBER_VIOLENCE_AGAINST_WOMEN', 'STATEMENT_CATEGORY_DATA_PROTECTION_AND_PRIVACY_VIOLATIONS', 'STATEMENT_CATEGORY_ILLEGAL_OR_HARMFUL_SPEECH', 'STATEMENT_CATEGORY_INTELLECTUAL_PROPERTY_INFRINGEMENTS', 'STATEMENT_CATEGORY_NEGATIVE_EFFECTS_ON_CIVIC_DISCOURSE_OR_ELECTIONS', 'STATEMENT_CATEGORY_NON_CONSENSUAL_BEHAVIOUR', 'STATEMENT_CATEGORY_NOT_SPECIFIED_NOTICE', 'STATEMENT_CATEGORY_PORNOGRAPHY_OR_SEXUALIZED_CONTENT', 'STATEMENT_CATEGORY_PROTECTION_OF_MINORS', 'STATEMENT_CATEGORY_RISK_FOR_PUBLIC_SECURITY', 'STATEMENT_CATEGORY_SCAMS_AND_FRAUD', 'STATEMENT_CATEGORY_SELF_HARM', 'STATEMENT_CATEGORY_SCOPE_OF_PLATFORM_SERVICE', 'STATEMENT_CATEGORY_OTHER_VIOLATION_TC', 'STATEMENT_CATEGORY_UNSAFE_AND_ILLEGAL_PRODUCTS', 'STATEMENT_CATEGORY_UNSAFE_AND_PROHIBITED_PRODUCTS', 'STATEMENT_CATEGORY_VIOLENCE'])
category_addition | List(Enum(categories=['STATEMENT_CATEGORY_ANIMAL_WELFARE', 'STATEMENT_CATEGORY_CONSUMER_INFORMATION', 'STATEMENT_CATEGORY_CYBER_VIOLENCE', 'STATEMENT_CATEGORY_CYBER_VIOLENCE_AGAINST_WOMEN', 'STATEMENT_CATEGORY_DATA_PROTECTION_AND_PRIVACY_VIOLATIONS', 'STATEMENT_CATEGORY_ILLEGAL_OR_HARMFUL_SPEECH', 'STATEMENT_CATEGORY_INTELLECTUAL_PROPERTY_INFRINGEMENTS', 'STATEMENT_CATEGORY_NEGATIVE_EFFECTS_ON_CIVIC_DISCOURSE_OR_ELECTIONS', 'STATEMENT_CATEGORY_NON_CONSENSUAL_BEHAVIOUR', 'STATEMENT_CATEGORY_NOT_SPECIFIED_NOTICE', 'STATEMENT_CATEGORY_PORNOGRAPHY_OR_SEXUALIZED_CONTENT', 'STATEMENT_CATEGORY_PROTECTION_OF_MINORS', 'STATEMENT_CATEGORY_RISK_FOR_PUBLIC_SECURITY', 'STATEMENT_CATEGORY_SCAMS_AND_FRAUD', 'STATEMENT_CATEGORY_SELF_HARM', 'STATEMENT_CATEGORY_SCOPE_OF_PLATFORM_SERVICE', 'STATEMENT_CATEGORY_OTHER_VIOLATION_TC', 'STATEMENT_CATEGORY_UNSAFE_AND_ILLEGAL_PRODUCTS', 'STATEMENT_CATEGORY_UNSAFE_AND_PROHIBITED_PRODUCTS', 'STATEMENT_CATEGORY_VIOLENCE']))
category_specification | List(Enum(categories=['KEYWORD_ANIMAL_HARM', 'KEYWORD_UNLAWFUL_SALE_ANIMALS', 'KEYWORD_HIDDEN_ADVERTISEMENT', 'KEYWORD_INSUFFICIENT_INFORMATION_ON_TRADERS', 'KEYWORD_MISLEADING_INFO_CONSUMER_RIGHTS', 'KEYWORD_MISLEADING_INFO_GOODS_SERVICES', 'KEYWORD_NONCOMPLIANCE_PRICING', 'KEYWORD_CYBER_BULLYING_INTIMIDATION', 'KEYWORD_CYBER_HARASSMENT', 'KEYWORD_CYBER_INCITEMENT', 'KEYWORD_CYBER_STALKING', 'KEYWORD_NON_CONSENSUAL_IMAGE_SHARING', 'KEYWORD_NON_CONSENSUAL_MATERIAL_DEEPFAKE', 'KEYWORD_BULLYING_AGAINST_GIRLS', 'KEYWORD_CYBER_HARASSMENT_AGAINST_WOMEN', 'KEYWORD_CYBER_STALKING_AGAINST_WOMEN', 'KEYWORD_FEMALE_GENDERED_DISINFORMATION', 'KEYWORD_INCITEMENT_AGAINST_WOMEN', 'KEYWORD_NON_CONSENSUAL_IMAGE_SHARING_AGAINST_WOMEN', 'KEYWORD_NON_CONSENSUAL_MATERIAL_DEEPFAKE_AGAINST_WOMEN', 'KEYWORD_BIOMETRIC_DATA_BREACH', 'KEYWORD_MISSING_PROCESSING_GROUND', 'KEYWORD_RIGHT_TO_BE_FORGOTTEN', 'KEYWORD_DATA_FALSIFICATION', 'KEYWORD_DEFAMATION', 'KEYWORD_DISCRIMINATION', 'KEYWORD_HATE_SPEECH', 'KEYWORD_COPYRIGHT_INFRINGEMENT', 'KEYWORD_DESIGN_INFRINGEMENT', 'KEYWORD_GEOGRAPHIC_INDICATIONS_INFRINGEMENT', 'KEYWORD_PATENT_INFRINGEMENT', 'KEYWORD_TRADE_SECRET_INFRINGEMENT', 'KEYWORD_TRADEMARK_INFRINGEMENT', 'KEYWORD_DISINFORMATION', 'KEYWORD_MISINFORMATION', 'KEYWORD_MISINFORMATION_DISINFORMATION', 'KEYWORD_VIOLATION_EU_LAW', 'KEYWORD_VIOLATION_NATIONAL_LAW', 'KEYWORD_FOREIGN_INFORMATION_MANIPULATION', 'KEYWORD_NON_CONSENSUAL_ITEMS_DEEPFAKE', 'KEYWORD_ONLINE_BULLYING_INTIMIDATION', 'KEYWORD_STALKING', 'KEYWORD_ADULT_SEXUAL_MATERIAL', 'KEYWORD_IMAGE_BASED_SEXUAL_ABUSE', 'KEYWORD_AGE_SPECIFIC_RESTRICTIONS_MINORS', 'KEYWORD_CHILD_SEXUAL_ABUSE_MATERIAL', 'KEYWORD_CHILD_SEXUAL_ABUSE_MATERIAL_DEEPFAKE', 'KEYWORD_GROOMING_SEXUAL_ENTICEMENT_MINORS', 'KEYWORD_UNSAFE_CHALLENGES', 'KEYWORD_ILLEGAL_ORGANIZATIONS', 'KEYWORD_RISK_ENVIRONMENTAL_DAMAGE', 'KEYWORD_RISK_PUBLIC_HEALTH', 'KEYWORD_TERRORIST_CONTENT', 'KEYWORD_INAUTHENTIC_ACCOUNTS', 'KEYWORD_INAUTHENTIC_LISTINGS', 'KEYWORD_INAUTHENTIC_USER_REVIEWS', 'KEYWORD_IMPERSONATION_ACCOUNT_HIJACKING', 'KEYWORD_PHISHING', 'KEYWORD_PYRAMID_SCHEMES', 'KEYWORD_CONTENT_PROMOTING_EATING_DISORDERS', 'KEYWORD_SELF_MUTILATION', 'KEYWORD_SUICIDE', 'KEYWORD_AGE_SPECIFIC_RESTRICTIONS', 'KEYWORD_GEOGRAPHICAL_REQUIREMENTS', 'KEYWORD_GOODS_SERVICES_NOT_PERMITTED', 'KEYWORD_LANGUAGE_REQUIREMENTS', 'KEYWORD_NUDITY', 'KEYWORD_INSUFFICIENT_INFORMATION_TRADERS', 'KEYWORD_PROHIBITED_PRODUCTS', 'KEYWORD_UNSAFE_PRODUCTS', 'KEYWORD_REGULATED_GOODS_SERVICES', 'KEYWORD_DANGEROUS_TOYS', 'KEYWORD_COORDINATED_HARM', 'KEYWORD_GENDER_BASED_VIOLENCE', 'KEYWORD_HUMAN_EXPLOITATION', 'KEYWORD_HUMAN_TRAFFICKING', 'KEYWORD_INCITEMENT_VIOLENCE_HATRED', 'KEYWORD_TRAFFICKING_WOMEN_GIRLS', 'KEYWORD_OTHER']))
category_specification_other | String
content_type | List(Enum(categories=['CONTENT_TYPE_APP', 'CONTENT_TYPE_AUDIO', 'CONTENT_TYPE_IMAGE', 'CONTENT_TYPE_PRODUCT', 'CONTENT_TYPE_SYNTHETIC_MEDIA', 'CONTENT_TYPE_TEXT', 'CONTENT_TYPE_VIDEO', 'CONTENT_TYPE_OTHER']))
content_type_other | String
content_language | Enum(categories=['AA', 'AB', 'AE', 'AF', 'AK', 'AM', 'AN', 'AR', 'AS', 'AV', 'AY', 'AZ', 'BA', 'BE', 'BG', 'BI', 'BM', 'BN', 'BO', 'BR', 'BS', 'CA', 'CE', 'CH', 'CO', 'CR', 'CS', 'CU', 'CV', 'CY', 'DA', 'DE', 'DV', 'DZ', 'EE', 'EL', 'EN', 'EO', 'ES', 'ET', 'EU', 'FA', 'FF', 'FI', 'FJ', 'FO', 'FR', 'FY', 'GA', 'GD', 'GL', 'GN', 'GU', 'GV', 'HA', 'HE', 'HI', 'HO', 'HR', 'HT', 'HU', 'HY', 'HZ', 'IA', 'ID', 'IE', 'IG', 'II', 'IK', 'IO', 'IS', 'IT', 'IU', 'JA', 'JV', 'KA', 'KG', 'KI', 'KJ', 'KK', 'KL', 'KM', 'KN', 'KO', 'KR', 'KS', 'KU', 'KV', 'KW', 'KY', 'LA', 'LB', 'LG', 'LI', 'LN', 'LO', 'LT', 'LU', 'LV', 'MG', 'MH', 'MI', 'MK', 'ML', 'MN', 'MR', 'MS', 'MT', 'MY', 'NA', 'NB', 'ND', 'NE', 'NG', 'NL', 'NN', 'NO', 'NR', 'NV', 'NY', 'OC', 'OJ', 'OM', 'OR', 'OS', 'PA', 'PI', 'PL', 'PS', 'PT', 'QU', 'RM', 'RN', 'RO', 'RU', 'RW', 'SA', 'SC', 'SD', 'SE', 'SG', 'SI', 'SK', 'SL', 'SM', 'SO', 'SN', 'SQ', 'SR', 'SS', 'ST', 'SU', 'SV', 'SW', 'TA', 'TE', 'TG', 'TH', 'TI', 'TK', 'TL', 'TN', 'TO', 'TR', 'TT', 'TW', 'TY', 'UG', 'UK', 'UR', 'UZ', 'VE', 'VI', 'VO', 'WA', 'WO', 'XH', 'YI', 'YO', 'ZA', 'ZH', 'ZU'])
content_date | Datetime(time_unit='ms', time_zone=None)
territorial_scope | List(Enum(categories=['EU', 'EEA', 'EEA_no_IS', 'AT', 'BE', 'BG', 'CY', 'CZ', 'DE', 'DK', 'EE', 'ES', 'FI', 'FR', 'GR', 'HR', 'HU', 'IE', 'IS', 'IT', 'LI', 'LT', 'LU', 'LV', 'MT', 'NL', 'NO', 'PL', 'PT', 'RO', 'SE', 'SI', 'SK']))
application_date | Datetime(time_unit='ms', time_zone=None)
decision_facts | String
source_type | Enum(categories=['SOURCE_ARTICLE_16', 'SOURCE_TRUSTED_FLAGGER', 'SOURCE_TYPE_OTHER_NOTIFICATION', 'SOURCE_VOLUNTARY'])
source_identity | String
automated_detection | Enum(categories=['Yes', 'No'])
automated_decision | Enum(categories=['AUTOMATED_DECISION_FULLY', 'AUTOMATED_DECISION_PARTIALLY', 'AUTOMATED_DECISION_NOT_AUTOMATED'])
platform_name | String
platform_uid | String
created_at | Datetime(time_unit='ms', time_zone=None)
released_on | Datetime(time_unit='ms', time_zone=None)

### meta.json

Column | Type
--- | ---
start_date | Date
end_date | Date
batch_count | Int64
total_rows | UInt64
total_rows_with_keywords | UInt64
batch_rows | UInt64
batch_rows_with_keywords | UInt64
batch_memory | UInt64
sha256 | String

### meta-statistics.parquet

Column | Type
--- | ---
start_date | Date
end_date | Date
total_rows | UInt64
total_rows_with_keywords | UInt64
batch_count | UInt64
rows | UInt64
keywords | UInt64
rows_with_keywords | UInt64
max_keywords_per_row | UInt32
null_decision | UInt64
visibility_decision_only | UInt64
monetary_decision_only | UInt64
provision_decision_only | UInt64
account_decision_only | UInt64
visibility_monetary_decision | UInt64
visibility_provision_decision | UInt64
visibility_account_decision | UInt64
monetary_provision_decision | UInt64
monetary_account_decision | UInt64
provision_account_decision | UInt64
monetary_provision_account_decision | UInt64
visibility_provision_account_decision | UInt64
visibility_monetary_account_decision | UInt64
visibility_monetary_provision_decision | UInt64
all_kinds_decision | UInt64
max_visibility_per_row | UInt64
visibility_values | UInt64
rows_with_visibility | UInt64
null_visibility_decision | UInt64
content_removed | UInt64
content_disabled | UInt64
content_demoted | UInt64
content_age_restricted | UInt64
content_interaction_restricted | UInt64
content_labeled | UInt64
other_visibility | UInt64
monetary_suspension | UInt64
monetary_termination | UInt64
monetary_other | UInt64
null_monetary_decision | UInt64
provision_partial_suspension | UInt64
provision_total_suspension | UInt64
provision_partial_termination | UInt64
provision_total_termination | UInt64
null_provision_decision | UInt64
account_suspended | UInt64
account_terminated | UInt64
null_account_decision | UInt64
account_type_business | UInt64
account_type_private | UInt64
null_account_type | UInt64
illegal_content | UInt64
incompatible_content | UInt64
null_decision_ground | UInt64
incompatible_content_illegal_yes | UInt64
incompatible_content_illegal_no | UInt64
null_incompatible_content_illegal | UInt64
account_suspended_null_date | UInt64
account_suspended_until_date | UInt64
account_terminated_null_date | UInt64
account_terminated_until_date | UInt64
source_article_16 | UInt64
source_trusted_flagger | UInt64
source_other_notification | UInt64
source_voluntary | UInt64
null_source_type | UInt64
automated_detection_yes | UInt64
automated_detection_no | UInt64
null_automated_detection | UInt64
automated_decision_fully | UInt64
automated_decision_partially | UInt64
automated_decision_not_automated | UInt64
null_automated_decision | UInt64
csam | UInt32
csam_null_decision | UInt32
csam_visibility_decision_only | UInt32
csam_monetary_decision_only | UInt32
csam_provision_decision_only | UInt32
csam_account_decision_only | UInt32
csam_visibility_monetary_decision | UInt32
csam_visibility_provision_decision | UInt32
csam_visibility_account_decision | UInt32
csam_monetary_provision_decision | UInt32
csam_monetary_account_decision | UInt32
csam_provision_account_decision | UInt32
csam_monetary_provision_account_decision | UInt32
csam_visibility_provision_account_decision | UInt32
csam_visibility_monetary_account_decision | UInt32
csam_visibility_monetary_provision_decision | UInt32
csam_all_kinds_decision | UInt32
csam_max_visibility_per_row | UInt32
csam_visibility_values | UInt32
csam_rows_with_visibility | UInt32
csam_null_visibility_decision | UInt32
csam_content_removed | UInt32
csam_content_disabled | UInt32
csam_content_demoted | UInt32
csam_content_age_restricted | UInt32
csam_content_interaction_restricted | UInt32
csam_content_labeled | UInt32
csam_other_visibility | UInt32
csam_monetary_suspension | UInt32
csam_monetary_termination | UInt32
csam_monetary_other | UInt32
csam_null_monetary_decision | UInt32
csam_provision_partial_suspension | UInt32
csam_provision_total_suspension | UInt32
csam_provision_partial_termination | UInt32
csam_provision_total_termination | UInt32
csam_null_provision_decision | UInt32
csam_account_suspended | UInt32
csam_account_terminated | UInt32
csam_null_account_decision | UInt32
csam_account_suspended_null_date | UInt32
csam_account_suspended_until_date | UInt32
csam_account_terminated_null_date | UInt32
csam_account_terminated_until_date | UInt32
csam_account_type_business | UInt32
csam_account_type_private | UInt32
csam_null_account_type | UInt32
csam_illegal_content | UInt32
csam_incompatible_content | UInt32
csam_null_decision_ground | UInt32
csam_incompatible_content_illegal_yes | UInt32
csam_incompatible_content_illegal_no | UInt32
csam_null_incompatible_content_illegal | UInt32
csam_source_article_16 | UInt32
csam_source_trusted_flagger | UInt32
csam_source_other_notification | UInt32
csam_source_voluntary | UInt32
csam_null_source_type | UInt32
csam_automated_detection_yes | UInt32
csam_automated_detection_no | UInt32
csam_null_automated_detection | UInt32
csam_automated_decision_fully | UInt32
csam_automated_decision_partially | UInt32
csam_automated_decision_not_automated | UInt32
csam_null_automated_decision | UInt32

### meta-keywords.parquet

Column | Type
--- | ---
start_date | Date
end_date | Date
keyword | Enum(categories=['KEYWORD_ANIMAL_HARM', 'KEYWORD_UNLAWFUL_SALE_ANIMALS', 'KEYWORD_HIDDEN_ADVERTISEMENT', 'KEYWORD_INSUFFICIENT_INFORMATION_ON_TRADERS', 'KEYWORD_MISLEADING_INFO_CONSUMER_RIGHTS', 'KEYWORD_MISLEADING_INFO_GOODS_SERVICES', 'KEYWORD_NONCOMPLIANCE_PRICING', 'KEYWORD_CYBER_BULLYING_INTIMIDATION', 'KEYWORD_CYBER_HARASSMENT', 'KEYWORD_CYBER_INCITEMENT', 'KEYWORD_CYBER_STALKING', 'KEYWORD_NON_CONSENSUAL_IMAGE_SHARING', 'KEYWORD_NON_CONSENSUAL_MATERIAL_DEEPFAKE', 'KEYWORD_BULLYING_AGAINST_GIRLS', 'KEYWORD_CYBER_HARASSMENT_AGAINST_WOMEN', 'KEYWORD_CYBER_STALKING_AGAINST_WOMEN', 'KEYWORD_FEMALE_GENDERED_DISINFORMATION', 'KEYWORD_INCITEMENT_AGAINST_WOMEN', 'KEYWORD_NON_CONSENSUAL_IMAGE_SHARING_AGAINST_WOMEN', 'KEYWORD_NON_CONSENSUAL_MATERIAL_DEEPFAKE_AGAINST_WOMEN', 'KEYWORD_BIOMETRIC_DATA_BREACH', 'KEYWORD_MISSING_PROCESSING_GROUND', 'KEYWORD_RIGHT_TO_BE_FORGOTTEN', 'KEYWORD_DATA_FALSIFICATION', 'KEYWORD_DEFAMATION', 'KEYWORD_DISCRIMINATION', 'KEYWORD_HATE_SPEECH', 'KEYWORD_COPYRIGHT_INFRINGEMENT', 'KEYWORD_DESIGN_INFRINGEMENT', 'KEYWORD_GEOGRAPHIC_INDICATIONS_INFRINGEMENT', 'KEYWORD_PATENT_INFRINGEMENT', 'KEYWORD_TRADE_SECRET_INFRINGEMENT', 'KEYWORD_TRADEMARK_INFRINGEMENT', 'KEYWORD_DISINFORMATION', 'KEYWORD_MISINFORMATION', 'KEYWORD_MISINFORMATION_DISINFORMATION', 'KEYWORD_VIOLATION_EU_LAW', 'KEYWORD_VIOLATION_NATIONAL_LAW', 'KEYWORD_FOREIGN_INFORMATION_MANIPULATION', 'KEYWORD_NON_CONSENSUAL_ITEMS_DEEPFAKE', 'KEYWORD_ONLINE_BULLYING_INTIMIDATION', 'KEYWORD_STALKING', 'KEYWORD_ADULT_SEXUAL_MATERIAL', 'KEYWORD_IMAGE_BASED_SEXUAL_ABUSE', 'KEYWORD_AGE_SPECIFIC_RESTRICTIONS_MINORS', 'KEYWORD_CHILD_SEXUAL_ABUSE_MATERIAL', 'KEYWORD_CHILD_SEXUAL_ABUSE_MATERIAL_DEEPFAKE', 'KEYWORD_GROOMING_SEXUAL_ENTICEMENT_MINORS', 'KEYWORD_UNSAFE_CHALLENGES', 'KEYWORD_ILLEGAL_ORGANIZATIONS', 'KEYWORD_RISK_ENVIRONMENTAL_DAMAGE', 'KEYWORD_RISK_PUBLIC_HEALTH', 'KEYWORD_TERRORIST_CONTENT', 'KEYWORD_INAUTHENTIC_ACCOUNTS', 'KEYWORD_INAUTHENTIC_LISTINGS', 'KEYWORD_INAUTHENTIC_USER_REVIEWS', 'KEYWORD_IMPERSONATION_ACCOUNT_HIJACKING', 'KEYWORD_PHISHING', 'KEYWORD_PYRAMID_SCHEMES', 'KEYWORD_CONTENT_PROMOTING_EATING_DISORDERS', 'KEYWORD_SELF_MUTILATION', 'KEYWORD_SUICIDE', 'KEYWORD_AGE_SPECIFIC_RESTRICTIONS', 'KEYWORD_GEOGRAPHICAL_REQUIREMENTS', 'KEYWORD_GOODS_SERVICES_NOT_PERMITTED', 'KEYWORD_LANGUAGE_REQUIREMENTS', 'KEYWORD_NUDITY', 'KEYWORD_INSUFFICIENT_INFORMATION_TRADERS', 'KEYWORD_PROHIBITED_PRODUCTS', 'KEYWORD_UNSAFE_PRODUCTS', 'KEYWORD_REGULATED_GOODS_SERVICES', 'KEYWORD_DANGEROUS_TOYS', 'KEYWORD_COORDINATED_HARM', 'KEYWORD_GENDER_BASED_VIOLENCE', 'KEYWORD_HUMAN_EXPLOITATION', 'KEYWORD_HUMAN_TRAFFICKING', 'KEYWORD_INCITEMENT_VIOLENCE_HATRED', 'KEYWORD_TRAFFICKING_WOMEN_GIRLS', 'KEYWORD_OTHER'])
count | UInt32

### meta-platforms.parquet

Column | Type
--- | ---
start_date | Date
end_date | Date
platform | String
total | UInt32
has_keyword | UInt32
is_csam | UInt32

## Keywords

keyword | count | pct
--- | --- | ---
enum | u32 | f64
KEYWORD_CHILD_SEXUAL_ABUSE_MATERIAL | 3,135,143 | 55.888
KEYWORD_OTHER | 1,854,134 | 33.052
KEYWORD_AGE_SPECIFIC_RESTRICTIONS_MINORS | 544,969 | 9.715
KEYWORD_GROOMING_SEXUAL_ENTICEMENT_MINORS | 72,325 | 1.289
KEYWORD_NUDITY | 1,633 | 0.029
KEYWORD_ONLINE_BULLYING_INTIMIDATION | 1,439 | 0.026
KEYWORD_HATE_SPEECH | 47 | 0.001
KEYWORD_ADULT_SEXUAL_MATERIAL | 17 | 0.000
KEYWORD_HUMAN_TRAFFICKING | 16 | 0.000
KEYWORD_REGULATED_GOODS_SERVICES | 2 | 0.000

## Platforms

index | platform
--- | ---
u32 | str
0 | AliExpress
1 | Badoo
2 | Booking.com
3 | Bumble
4 | Campfire
5 | Canva
6 | Chrome Web Store
7 | Dailymotion
8 | Discord Netherlands B.V.
9 | Facebook
10 | Google Maps
11 | Google Play
12 | Google Shopping
13 | Habbo
14 | Hinge
15 | Hotel Hideaway
16 | Idealo
17 | Instagram
18 | Kleinanzeigen
19 | Meetic SAS
20 | OTTO Market
21 | Pinterest
22 | Pornhub
23 | Quora Ireland Limited
24 | Rajče
25 | Reddit
26 | Roblox
27 | Snapchat
28 | Stripchat
29 | Temu
30 | Threads
31 | TikTok
32 | Tinder
33 | VSCO
34 | Vinted UAB
35 | Wallapop
36 | WhatsApp Channels
37 | X
38 | YouTube
39 | Zalando
40 | bolha.com
41 | leboncoin
42 | willhaben internet service GmbH & Co KG
43 | www.gutefrage.net

## Timelines

### CSAM SoRs